@@ -2,6 +2,7 @@ import logging
 
 from functools import wraps
 from motor.motor_asyncio import AsyncIOMotorCollection, AsyncIOMotorClient
+from pymongo import MongoClient
 
 from .document_dict import DocumentDict
 from .document_array import DocumentArray
@@ -124,6 +125,10 @@ class MetaDocument(type):
     client: AsyncIOMotorClient
     collection: AsyncIOMotorCollection
 
+    def __init__(cls, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        cls.create_indexes()
+
     @property
     def collection(cls) -> AsyncIOMotorCollection:
         for field in ("client", "database", "collection"):
@@ -138,6 +143,19 @@ class MetaDocument(type):
 
         return client[database][collection]
 
+    @property
+    def sync_collection(cls):
+        for field in ("client", "database", "collection"):
+            if field not in cls.__dict__:
+                raise type("{}NotFound".format(field.capitalize()), (DocumentException,), {})(
+                    f"Required attribute {field} is missing."
+                )
+
+        client = cls.__dict__["client"]
+        database = cls.__dict__["database"]
+        collection = cls.__dict__["collection"]
+        return client.delegate[database][collection]
+
     def __getattribute__(cls, item: str):
         if item in ("database", "client"):
             raise AttributeError(item)
@@ -147,6 +165,12 @@ class MetaDocument(type):
     def Field(cls):
         return DocumentField(cls)
 
+    def create_indexes(cls):
+        """Called on class creation. Made for automatic indexes creation.
+        Can be implemented in subclass (Optional).
+        Here cls.sync_collection should be used.
+        """
+
 
 class Document(metaclass=MetaDocument):
     Relations = DocumentRelations()
@@ -158,7 +182,7 @@ class Document(metaclass=MetaDocument):
     def __repr__(self):
         return "{0}({1})".format(
             self.__class__.__name__,
-            ", ".join(f"{key}={value}" for key, value in self._document_.items())
+            ", ".join(f"{key}={value}" for key, value in self.items())
         )
 
     def __getattribute__(self, item):
@@ -246,10 +270,10 @@ class Document(metaclass=MetaDocument):
 
     @classmethod
     @check_setup
-    async def many(cls, **kwargs) -> list:
+    async def many(cls, **kwargs) -> DocumentArray:
         """Finds multiple documents based on kwargs."""
 
-        result_list = []
+        result_list = DocumentArray()
         cursor = cls.collection.find(kwargs)
         async for doc in cursor:
             result_list.append(cls(**doc))
@@ -320,3 +344,10 @@ class Document(metaclass=MetaDocument):
             return result
 
         return func_wrapper
+
+    def to_json(self):
+        _id = self._id
+        result = {"_id": str(self._document_.__data__.pop("_id"))}
+        result.update(self._document_.__data__)
+        self._document_["_id"] = _id
+        return result
